Web Mercator Tiles
Rust crate to convert lon/lat coordinates to Web Mercator tiles.
See https://wiki.openstreetmap.org/wiki/Slippy_map_tilenames for details.
Warning
All the functions provided by this crate do not check the validity of the input. However, since they are based on equations, they will still return an (invalid) result.
Functions
- lonlat2tile
- Convert lon/lat coordinates to a Web Mercator tile at a given zoom level.
- tile2lonlat
- Convert a Web Mercator tile to lon/lat coordinates at a given zoom level.
- zoom_in
- Zoom in from the given tile.
- zoom_
out - Zoom out from the given tile.